import nock from 'nock';
import axios from 'axios';
import httpAdapter from 'axios/lib/adapters/http';

import os from 'os';
import fs from 'fs';
import path from 'path';
import rimraf from 'rimraf';

import loader from '../src';

axios.defaults.adapter = httpAdapter;

let dir = '';
const dirs = [];
beforeEach(() => {
  dir = fs.mkdtempSync(path.join(os.tmpdir(), './'));
  dirs.push(dir);
});
afterAll(() => {
  dirs.forEach(d => rimraf(d, () => {}));
});

test('save page', () => {
  expect.assertions(3);

  const host = 'http://test.com';

  nock(host)
    .get('/page')
    .reply(200, fs.readFileSync(path.resolve('__tests__/fixtures/page.html'), 'utf8'));

  const favicon = fs.readFileSync(path.resolve('__tests__/fixtures/favicon.ico'));
  nock(host)
    .get('/assets/icons/default/favicon.ico')
    .reply(200, favicon);

  const ruby = fs.readFileSync(path.resolve('__tests__/fixtures/ruby.png'));
  nock(host)
    .get('/images/ruby.png')
    .reply(200, ruby);

  const page = `${host}/page`;

  const filepath = path.join(dir, 'test-com-page.html');
  const dirFiles = path.join(dir, 'test-com-page_files');
  const faviconFilepath = path.join(dirFiles, 'assets-icons-default-favicon.ico');
  const rubyFilepath = path.join(dirFiles, 'images-ruby.png');
  return loader(page, dir)
    .then(() => fs.readFileSync(filepath, 'utf8'))
    .then(data => expect(data).toBe(fs.readFileSync(path.resolve('__tests__/fixtures/savedPage.html'), 'utf8')))
    .then(() => fs.readFileSync(faviconFilepath, 'utf8'))
    .then(data => expect(data).toBe(favicon.toString()))
    .then(() => fs.readFileSync(rubyFilepath, 'utf8'))
    .then(data => expect(data).toBe(ruby.toString()));
});

test('missing page', () => {
  expect.assertions(1);

  const host = 'http://test.com';

  nock(host)
    .get('/missing_page')
    .reply(404);

  const page = `${host}/missing_page`;

  return loader(page, dir)
    .catch(e => expect(e.errno).toBe(1));
});

test('a file page exist', () => {
  expect.assertions(1);

  const host = 'http://test.com';

  const file = '<!DOCTYPE html><html><body></body></html>';
  nock(host)
    .get('/pageExist')
    .reply(200, file);

  const page = `${host}/pageExist`;

  const filepath = path.join(dir, 'test-com-pageExist.html');
  fs.writeFileSync(filepath, file);
  return loader(page, dir)
    .catch(e => expect(e.errno).toBe(2));
});

test('output directory does not exist', () => {
  expect.assertions(1);

  const host = 'http://test.com';

  const file = '<!DOCTYPE html><html><body></body></html>';
  nock(host)
    .get('/page')
    .reply(200, file);

  const page = `${host}/page`;
  const dirNotExist = path.join(os.tmpdir(), './NotExist');

  return loader(page, dirNotExist)
    .catch(e => expect(e.errno).toBe(3));
});
