import fs from 'mz/fs';

import errors from './errno';
import LoaderError from './LoaderError';

const throwPathNotExists = (path) => {
  const message = `path does not exists ${path}`;
  throw (new LoaderError(errors.code.ENOENT, message));
};

export const CheckExistDir = path =>
  fs.stat(path)
    .catch((err) => {
      if (err.code === 'ENOENT') {
        throwPathNotExists(path);
      }
      throw err;
    })
    .then((stat) => {
      if (!stat || !stat.isDirectory()) {
        throwPathNotExists(path);
      }
    });

export const CheckCreation = path =>
  fs.stat(path)
    .catch((err) => {
      if (err.code === 'ENOENT') {
        return;
      }
      throw err;
    })
    .then((stat) => {
      if (stat) {
        const message = `path already exists ${path}`;
        throw (new LoaderError(errors.code.EEXIST, message));
      }
    });
