import createDebug from 'debug';

import axios from 'axios';
import fs from 'mz/fs';

import { CheckCreation } from './fs';

import errors from './errno';
import LoaderError from './LoaderError';

const debug = createDebug('page-loader:loader');

const throwUnavailableLink = (err, link) => {
  const message = `unavailable link ${link} due to reason: ${err.message}`;
  throw (new LoaderError(errors.code.EUNAVLINK, message));
};

export const getHtml = link =>
  axios.get(link)
    .catch(err => throwUnavailableLink(err, link))
    .then(res => res.data);

const loadFile = (link, filepath) => {
  debug('start load a file %s', link);
  CheckCreation(filepath)
    .then(() => axios({
      method: 'get',
      url: link,
      responseType: 'stream' }))
    .catch(err => throwUnavailableLink(err, link))
    .then(res => res.data.pipe(fs.createWriteStream(filepath)))
    .then(() => debug('end load a file %s', link));
};

export const loadFiles = (exchanges) => {
  debug('start load local links');
  return Promise.all(exchanges.map(exch =>
    loadFile(exch.link, exch.path)))
    .then(() => debug('end load local links'));
};
