import url from 'url';
import path from 'path';

const toKebabCase = str =>
  str
    .replace(/\W*(.*)/g, '$1')
    .replace(/\W/g, '-');

const linkToNativelName = (urlPage) => {
  const { hostname, pathname } = url.parse(urlPage);
  const parse = path.parse(pathname);
  const pathWithoutExt = path.format({ ...parse, ext: '', base: '' });
  const str = toKebabCase(url.format({ hostname, pathname: pathWithoutExt }));
  return `${str}${parse.ext}`;
};

const nativeLink = (link, local) =>
  path.join(local, linkToNativelName(link));

export const basicNames = (page, dir) => {
  const pageName = linkToNativelName(page);
  const filename = `${pageName}.html`;
  const filepath = path.join(dir, filename);
  const simpleDirFiles = `${pageName}_files`;
  const dirFiles = path.join(dir, simpleDirFiles);
  return {
    filepath,
    simpleDirFiles,
    dirFiles,
  };
};

export const fullLink = (link, urlData) => {
  if (url.parse(link).hostname) {
    return link;
  }
  return url.format({ ...urlData, pathname: link });
};

export const exchangeToNativLinks = (links, local) =>
  links.map((link) => {
    const exch = { link, nativeLink: nativeLink(link, local) };
    return exch;
  });
